@@ -62,6 +62,17 @@ class TestApp(unittest.TestCase):
             ),
         )
 
+        # Site restricted search
+        self.app.add_url_rule(
+            "/server/docs/search",
+            "server-docs-search",
+            build_search_view(
+                session=session,
+                template_path="docs/search.html",
+                site_restricted_search=True,
+            ),
+        )
+
         self.client = self.app.test_client()
 
     def tearDown(self):
@@ -76,13 +87,15 @@ class TestApp(unittest.TestCase):
         # Delete API key
         del os.environ["SEARCH_API_KEY"]
 
-        # Check we get 500 error without debug mode on
-        output = io.StringIO()
-        with redirect_stderr(output):
-            error_response = self.client.get("/search?q=snap")
+        # it's not possible to redirect stderr in Github action
+        if not os.getenv("GITHUB_ACTIONS"):
+            # Check we get 500 error without debug mode on
+            output = io.StringIO()
+            with redirect_stderr(output):
+                error_response = self.client.get("/search?q=snap")
 
-        self.assertIn("NoAPIKeyError", output.getvalue())
-        self.assertEqual(error_response.status_code, 500)
+            self.assertIn("NoAPIKeyError", output.getvalue())
+            self.assertEqual(error_response.status_code, 500)
 
         # Now turn debug mode on, check we get the direct error
         self.app.debug = True
@@ -206,3 +219,30 @@ class TestApp(unittest.TestCase):
         # Check next page
         self.assertIn(b"Next docs page offset: 11", docs_response.data)
         self.assertNotIn(b"Previous", docs_response.data)
+
+    def test_site_restricted_search(self):
+        """
+        Check we can get results with site restricted search
+        """
+
+        search_response = self.client.get(
+            "/server/docs/search?q=packer&start=20&num=3"
+        )
+
+        # Check for success
+        self.assertEqual(search_response.status_code, 200)
+        # Check an item
+        self.assertIn(
+            (
+                b"- https://docs.<b>snap</b>craft.io/<b>snaps</b>hots: "
+                b"Snapshots - <b>Snap</b> documentation"
+            ),
+            search_response.data,
+        )
+        self.assertNotIn(
+            (
+                b"- https://docs.<b>snap</b>craft.io/ros-applications: "
+                b"ROS applications - <b>Snap</b> documentation"
+            ),
+            search_response.data,
+        )
